pub struct SharpParams {
pub threshold: f64,
pub radius_factor: f64,
}Expand description
SHARP background field removal
Uses spherical mean value (SMV) filtering to remove background field. The local field is obtained by deconvolving the SMV-filtered field.
Arguments
field- Unwrapped total field (nx * ny * nz)mask- Binary mask (nx * ny * nz), 1 = inside ROInx,ny,nz- Array dimensionsvsx,vsy,vsz- Voxel sizes in mmradius- SMV kernel radius in mmthreshold- High-pass filter threshold (typically 0.05)
SHARP algorithm parameters
Fields
threshold: f64Deconvolution threshold
radius_factor: f64Kernel radius factor (multiplied by min voxel size to get radius in mm; default: 18.0)